/*
	Anynome - The Generalized Metronome

    Copyright (C) 2007  Nigel D. Stepp

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

    Nigel Stepp <stepp@atistar.net>

    $Id: plugin_constant.c 132 2007-08-30 01:38:47Z stepp $
*/


#include "plugin_common.h"

#define PLUGIN_LABEL "constant"

// Define plugin parameters here
struct {
	// delay in miliseconds
	uint32_t delay;
} plugin_config;


void set_args(int argc, char *argv[], int opt_ind)
{
	int c;
	
	// set defaults
	plugin_config.delay = 1000;

	// Some getopt implementations don't preserve optind
	if( optind < opt_ind ) {
		optind = opt_ind;
	}
	while( (c = getopt(argc, argv, "d:h")) != -1 ) {
		switch(c) {
			case 'd':
				plugin_config.delay = atoi(optarg);
				if( plugin_config.delay <= 0 ) {
					plugin_error(PLUGIN_LABEL, "Delay (-d) must be a strictly positive integer.");
					exit(1);
				}
				break;
			case '?':
			case 'h':
			default:
				show_help();
				exit(0);
		}
	}
}

void get_delay_series(uint32_t *delay_data, int num_events)
{
	int i;


	if( !delay_data || num_events <= 0 ) {
		return;
	}


	for( i=0; i<num_events; i++ ) {
		// delay_data is expected to be in microseconds
		delay_data[i] = plugin_config.delay * 1000;
	}
}

void show_help(void)
{
	printf("Plugin Parameters (%s):\n", PLUGIN_LABEL);
	printf("  -d delay \tTime between stimuli in miliseconds (default: 1000)\n");
	printf("  -h       \tPlugin help\n");
	printf("\n");
}

