/*
	Anynome - The Generalized Metronome

    Copyright (C) 2007  Nigel D. Stepp

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

    Nigel Stepp <stepp@atistar.net>

    $Id: plugin_file.c 132 2007-08-30 01:38:47Z stepp $
*/


#include "plugin_common.h"

#define PLUGIN_LABEL "file"

// Define plugin parameters here
struct {
	FILE *delay_file;
} plugin_config;


void set_args(int argc, char *argv[], int opt_ind)
{
	int c;
	
	// set defaults
	plugin_config.delay_file = NULL;

	// Some getopt implementations don't preserve optind
	if( optind < opt_ind ) {
		optind = opt_ind;
	}
	while( (c = getopt(argc, argv, "f:h")) != -1 ) {
		switch(c) {
			case 'f':
				plugin_config.delay_file = fopen(optarg,"r");
				if( !plugin_config.delay_file ) {
					plugin_error(PLUGIN_LABEL, "Unable to open delay file.");
					perror(PLUGIN_LABEL);
					exit(1);
				}
				break;
			case '?':
			case 'h':
			default:
				show_help();
				exit(0);
		}
	}
}

void get_delay_series(uint32_t *delay_data, int num_events)
{
	int i;
	int len=16;
	uint32_t delay;
	char line[16];


	if( !delay_data || num_events <= 0 ) {
		return;
	}


	if( !plugin_config.delay_file ) {
		plugin_error(PLUGIN_LABEL, "Delay file is not open!");
		exit(1);
	}


	for( i=0; i<num_events; i++ ) {
		if( feof(plugin_config.delay_file) ) {
			plugin_error(PLUGIN_LABEL, "Ran out of file before we got to num_events");
			break;
		}

		fgets(line, len-1, plugin_config.delay_file);
		delay = atoi(line);

		if( delay <= 0 ) {
			fprintf(stderr, "%s: Error reading in a number at line %d, bailing.\n", PLUGIN_LABEL, i+1);
			exit(1);
		}

		delay_data[i] = delay;
	}

	fclose(plugin_config.delay_file);
}

void show_help(void)
{
	printf("Plugin Parameters (%s):\n", PLUGIN_LABEL);
	printf("  -f file  \tFile which contains a single column of delay times\n");
	printf("  -h       \tPlugin help\n");
	printf("\n");
}

